==> liquidwar6-0.2.3551.tar.gz: liquidwar6-0.2.3551/src/lib/gfx/mod-gl1/gl1-utils/gl1-utils-timer.c <==
/*
  Liquid War 6 is a unique multiplayer wargame.
  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014  Christian Mauduit <ufoot@ufoot.org>

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation, either version 3 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program.  If not, see <http://www.gnu.org/licenses/>.


  Liquid War 6 homepage : http://www.gnu.org/software/liquidwar6/
  Contact author        : ufoot@ufoot.org
*/

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include "../../gfx.h"
#include "gl1-utils.h"

extern int64_t
mod_gl1_utils_timer_get_bitmap_refresh (mod_gl1_utils_context_t *
					utils_context)
{
  return utils_context->timer.bitmap_refresh;
}

extern void
mod_gl1_utils_timer_set_bitmap_refresh (mod_gl1_utils_context_t *
					utils_context)
{
#if LW6_MS_WINDOWS || LW6_MAC_OS_X
  lw6sys_log (LW6SYS_LOG_INFO,
	      _x_
	      ("forcing the purge of textures now, OpenGL context might be lost"));
  mod_gl1_utils_bitmap_hash_refresh (utils_context);
#endif
  utils_context->timer.bitmap_refresh =
    _lw6gfx_sdl_timer_get_timestamp (&(utils_context->sdl_context));
}

==> liquidwar6-0.6.3902.tar.gz: liquidwar6-0.6.3902/src/lib/gfx/mod-gl1/gl1-utils/gl1-utils-timer.c <==
/*
  Liquid War 6 is a unique multiplayer wargame.
  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation, either version 3 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program.  If not, see <http://www.gnu.org/licenses/>.


  Liquid War 6 homepage : http://www.gnu.org/software/liquidwar6/
  Contact author        : ufoot@ufoot.org
*/

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include "../../gfx.h"
#include "gl1-utils.h"

extern int64_t
mod_gl1_utils_timer_get_bitmap_refresh (lw6sys_context_t * sys_context, mod_gl1_utils_context_t * utils_context)
{
  return utils_context->timer.bitmap_refresh;
}

extern void
mod_gl1_utils_timer_set_bitmap_refresh (lw6sys_context_t * sys_context, mod_gl1_utils_context_t * utils_context)
{
#if LW6_MS_WINDOWS || LW6_MAC_OS_X
  lw6sys_log (sys_context, LW6SYS_LOG_INFO, _x_ ("forcing the purge of textures now, OpenGL context might be lost"));
  mod_gl1_utils_bitmap_hash_refresh (sys_context, utils_context);
#endif
  utils_context->timer.bitmap_refresh = _lw6gfx_sdl_timer_get_timestamp (sys_context, &(utils_context->sdl_context));
}
